// Henrik Gemal - http://linky.mozdev.org

// product related settings
// you can change these
const myProductName = "Linky";
const myProductRegKey = "linky";
const myProductRegVersion = "1.6.0";
const myProductRegVersionBuild = "20030507";
const myJarFileName = "linky.jar";
const myJarFileSize = 15; // the filesize in KB of myJarFileName
const myJSFileName = "linky.js"; // the default prefs file. set it to "" if not used
const myJSFileSize = 1; // the filesize in KB of myJSFileName
const myLocales = new Array("en-US", "da-dk"); // the locales available

// global settings
// dont change these
const sysChromeGlobal = getFolder("Chrome");
const sysChromeGlobalJar = getFolder("Chrome", myJarFileName);
const sysChromeUser = getFolder("Current User","chrome");
const sysChromeUserJar = getFolder("Current User", "chrome/" + myJarFileName);
const errPage = "http://devedge.netscape.com/library/manuals/2001/xpinstall/1.0/err.html";

// verify disk space in kilobytes
function verifyDiskSpace(dirPath, spaceRequired) {
	var spaceAvailable = fileGetDiskSpaceAvailable(dirPath);
	if (parseInt(spaceAvailable/1024) < spaceRequired) {
		logComment("Insufficient disk space: " + dirPath + "\n\trequired : " + spaceRequired + " K\n\tavailable: " + spaceAvailable + " K");
		return(false);
	} else {
		return(true);
	}
}

var inst;
// inst is the installation method:
//		0 means that the installation was cancelled.
//		1 is in the global chrome folder. This *has* to be the default!
//		2 in in the personal profile folder. This is only supported for newer builds.

// Can we install in the personal profile folder?
if (buildID && buildID >= 2003030700) {
	alert("You can install " + myProductName + " " + myProductRegVersion + " in two ways:\n\n1) in the global chrome folder. This will make " + myProductName + " available in all profiles.\n\n2) in the personal profile folder. This will make " + myProductName + " available only in the current profile.\n\nYou will now be prompted to select a way...");
	var ans = confirm("Click OK to install in the global chrome folder:\n" + sysChromeGlobal + "\nThis is the recommended install option!");
	if (!ans) {
		ans = confirm("Click OK to install in your personal profile folder:\n" + sysChromeUser);
		if (!ans) {
			alert("You didn't choose any of the supported installation options!\nPlease restart the installation!");
			inst = 0;
		} else {
			inst = 2;
		}
	} else {
		inst = 1;
	}
} else {
	ans = confirm("Click OK to install " + myProductName + " " + myProductRegVersion + " in the global chrome folder:\n" + sysChromeGlobal);
	if (!ans) {
		alert("You didn't choose any of the supported installation options!\nPlease restart the installation!");
		inst = 0;
	} else {
		inst = 1;
	}
}

// did the user cancel?
if (inst) {
	var err;
	var err_tmp;

	logComment(myProductName + " version " + myProductRegVersion + " being installed on " + buildID);
	logComment("Installation method is " + inst);

	// init the installation
	err_tmp = initInstall(myProductName, myProductRegKey, myProductRegVersion + "." + myProductRegVersionBuild);
	if (err_tmp) {
		err = err_tmp;
	}

	// check if there's disk space for myJSFileSize
	if (!err && !verifyDiskSpace(sysChromeGlobal,myJSFileSize)) {
		err = INSUFFICIENT_DISK_SPACE;
	}

	// check if there's disk space for myJarFileSize
	if (!err && !verifyDiskSpace((inst == 1 ? sysChromeGlobal : sysChromeUser), myJarFileSize)) {
		err = INSUFFICIENT_DISK_SPACE;
	}

	// add the default prefs, but only if we have to install into global chrome
	if (!err && inst == 1 && myJSFileName) {
		err_tmp = addFile(myProductName, myJSFileName, getFolder("Program","defaults/pref"), myJSFileName);
		if (err_tmp) {
			logComment("Problem adding the pref defaults to: " + getFolder("Program", "defaults/pref") + "\n\tError code: " + err_tmp);
			err = err_tmp;
		}
	}
	
	// add the jar file
	if (!err) {
		if (inst == 2) {
			err_tmp = addFile(myProductName, myJarFileName, sysChromeUser, "");
		} else {
			err_tmp = addFile(myProductName, myJarFileName, sysChromeGlobal, "");
		}
		if (err_tmp) {
			logComment("Problem adding jar file. Error code: " + err_tmp);
			err = err_tmp;
		} else {
			logComment("ok adding jar file.");
		}
	}
		
	// register the content
	if (!err) {
		if (inst == 2) {
			err_tmp = registerChrome(PACKAGE | PROFILE_CHROME, sysChromeUserJar, "content/" + myProductRegKey + "/");
		} else {
			err_tmp = registerChrome(PACKAGE | DELAYED_CHROME, sysChromeGlobalJar, "content/" + myProductRegKey + "/");
		}
		if (err_tmp) {
			logComment("Problem registering the content chrome. Error code: " + err_tmp);
			err = err_tmp;
		} else {
			logComment("ok registering the content chrome.");
		}
	}
	
	// register the locale
	if (!err) {
		if (inst == 2) {
			for (var i = 0; i < myLocales.length; i++) {
				err_tmp = registerChrome(LOCALE | PROFILE_CHROME, sysChromeUserJar, "locale/" + myLocales[i] + "/" + myProductRegKey + "/");
				if (err_tmp)
					break;
			}
		} else {
			for (var i = 0; i < myLocales.length; i++) {
				err_tmp = registerChrome(LOCALE | DELAYED_CHROME, sysChromeGlobalJar, "locale/" + myLocales[i] + "/" + myProductRegKey + "/");
				if (err_tmp) {
					break;
				}
			}
		}
		if (err_tmp) {
			logComment("Problem registering the locale chrome. Error code: " + err_tmp);
			err = err_tmp;
		} else {
			logComment("ok registering the locale chrome.");
		}
	}
	
	// do the install
	if (!err) {
		err_tmp = performInstall();
		if (err_tmp < 0) {
			logComment("Problem performing install. Error code: " + err_tmp);
			err = err_tmp;
		} else {
			alert(myProductName + " version " + myProductRegVersion + " has been successfully installed!\nWhen you right-click on a webpage your will now have a new context menuitem called " + myProductName + "!\n\nYou must restart your browser to complete installation!");
		}
	}
		
	// did it work?
	if (err) {
		logComment("Problem installing. Error code: " + err + ". Error codes can been seen at: " + errPage);
		alert(myProductName + " version " + myProductRegVersion + " was not installed!\nError code: " + err + "\n\nError codes can been seen at:\n" + errPage)
		cancelInstall(err);
	}
} else {
	cancelInstall();
}
